abacusai.feature — AbacusAI documentation

# abacusai.feature

## Classes

`NestedFeature` | A nested feature in a feature group
`PointInTimeFeature` | A point-in-time feature description
`AbstractApiClass` |
`Feature` | A feature in a feature group

## Module Contents

class abacusai.feature.NestedFeature(client, name=None, selectClause=None, featureType=None, featureMapping=None, dataType=None, sourceTable=None, originalName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A nested feature in a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column

    - selectClause (str) – The sql logic for creating this feature’s data

    - featureType (str) – Feature Type of the Feature

    - featureMapping (str) – The Feature Mapping of the feature

    - dataType (str) – Data Type of the Feature

    - sourceTable (str) – The source table of the column

    - originalName (str) – The original name of the column

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.feature.PointInTimeFeature(client, historyTableName=None, aggregationKeys=None, timestampKey=None, historicalTimestampKey=None, lookbackWindowSeconds=None, lookbackWindowLagSeconds=None, lookbackCount=None, lookbackUntilPosition=None, expression=None, groupName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A point-in-time feature description

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - historyTableName (str) – The name of the history table. If not specified, the current table is used for a self-join.

    - aggregationKeys (list[str]) – List of keys to use for joining the historical table and performing the window aggregation.

    - timestampKey (str) – Name of feature which contains the timestamp value for the point-in-time feature.

    - historicalTimestampKey (str) – Name of feature which contains the historical timestamp.

    - lookbackWindowSeconds (float) – If window is specified in terms of time, the number of seconds in the past from the current time for the start of the window.

    - lookbackWindowLagSeconds (float) – Optional lag to offset the closest point for the window. If it is positive, the start of the window is delayed. If it is negative, we are looking at the “future” rows in the history table.

    - lookbackCount (int) – If window is specified in terms of count, the start position of the window (0 is the current row).

    - lookbackUntilPosition (int) – Optional lag to offset the closest point for the window. If it is positive, the start of the window is delayed by that many rows. If it is negative, we are looking at those many “future” rows in the history table.

    - expression (str) – SQL aggregate expression which can convert a sequence of rows into a scalar value.

    - groupName (str) – The group name this point-in-time feature belongs to.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.feature.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature.Feature(client, name=None, selectClause=None, featureMapping=None, sourceTable=None, originalName=None, usingClause=None, orderClause=None, whereClause=None, featureType=None, dataType=None, detectedFeatureType=None, detectedDataType=None, columns={}, pointInTimeInfo={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A feature in a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column

    - selectClause (str) – The sql logic for creating this feature’s data

    - featureMapping (str) – The Feature Mapping of the feature

    - sourceTable (str) – The source table of the column

    - originalName (str) – The original name of the column

    - usingClause (str) – Nested Column Using Clause

    - orderClause (str) – Nested Column Ordering Clause

    - whereClause (str) – Nested Column Where Clause

    - featureType (str) – Feature Type of the Feature

    - dataType (str) – Data Type of the Feature

    - detectedFeatureType (str) – The detected feature type of the column

    - detectedDataType (str) – The detected data type of the column

    - columns (NestedFeature) – Nested Features

    - pointInTimeInfo (PointInTimeFeature) – Point in time column information

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict